Index: src/heap/heap.h |
diff --git a/src/heap/heap.h b/src/heap/heap.h |
index 5c825e77804ad06cd30b1f3ae3ae6b4d562bcd86..0433bf7ecc8e0132cb5693a910547c24a0927b92 100644 |
--- a/src/heap/heap.h |
+++ b/src/heap/heap.h |
@@ -853,8 +853,8 @@ class Heap { |
// Clear the Instanceof cache (used when a prototype changes). |
inline void ClearInstanceofCache(); |
- // Iterates the whole code space to clear all ICs of the given kind. |
- void ClearAllICsByKind(Code::Kind kind); |
+ // Iterates the whole code space to clear all keyed store ICs. |
+ void ClearAllKeyedStoreICs(); |
// FreeSpace objects have a null map after deserialization. Update the map. |
void RepairFreeListsAfterDeserialization(); |